# OSAdvise

OSAdvise is a description of choices to have optimization on specific operating system
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**enabled** | **bool** | Enable operating system optimization not enabled by default. | [optional] 
**os_version** | **str** | Specific operating system version that can have optimization. | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


